"""Conversations: A python library for analysis of conversations."""
from ._conversations import Conversation, load_conversation
